pub fn user_message(context: &PromptContext, lang: Language) -> StringExpand description
Build the user message with spec, skeleton, contracts, and test harness.
pub fn user_message(context: &PromptContext, lang: Language) -> StringBuild the user message with spec, skeleton, contracts, and test harness.